/**
 * @copyright nhcarrigan
 * @license Naomi's Public License
 * @author Naomi Carrigan
 */
import Image from "next/image";
import type { JSX } from "react";

interface CharacterProperties {
  readonly id:       string;
  readonly onClick?: ()=> void;
  readonly focused:  boolean;
}

/**
 * Renders the view for a legacy character.
 * @param properties - The character to render.
 * @returns A JSX element.
 */
export const CharacterComponent = (
  properties: CharacterProperties,
): JSX.Element => {
  const { id, onClick, focused } = properties;

  return (
    <Image
      alt={id}
      className="m-h-[525px] m-w-[400px] object-contain"
      height={525}
      onClick={onClick}
      src={`https://cdn.nhcarrigan.com/characters/${id}.png`}
      style={focused
        ? { border: "4px solid yellow" }
        : {}}
      width={400}
    />
  );
};
